@@ -257,7 +257,7 @@ class PlotBucketMethod:
         )
 
 
-def weight_plot(stats: pd.DataFrame):
+def weight_plot(stats: pd.DataFrame, format=None, scale=None, width=None, height=None):
 
     """
     Generates a weight plot(plotly chart) from `stats`
@@ -266,19 +266,24 @@ def weight_plot(stats: pd.DataFrame):
     ```from skorecard.datasets import load_uci_credit_card
     from skorecard.bucketers import EqualFrequencyBucketer
     from skorecard.linear_model import LogisticRegression
-    from skorecard.reporting.plotting import weight_plot
+    from skorecard.reporting import weight_plot
     from sklearn.pipeline import Pipeline
-    from sklearn.preprocessing import OneHotEncoder
     X, y = load_uci_credit_card(return_X_y=True)
     pipeline = Pipeline([
         ('bucketer', EqualFrequencyBucketer(n_bins=10)),
         ('clf', LogisticRegression(calculate_stats=True))
     ])
     pipeline.fit(X, y)
-    assert pipeline.named_steps['clf'].p_val_coef_[0][0] > 0
     stats = pipeline.named_steps['clf'].get_stats()
 
     weight_plot(stats)```
+
+    Args:
+        stats: The statistics to display
+        format: The format of the image, such as 'png'. The default None returns a plotly image.
+        scale: If format is specified, the scale of the image
+        width: If format is specified, the width of the image
+        height: If format is specified, the image of the image
     """
     fig = go.Figure()
 
@@ -315,4 +320,9 @@ def weight_plot(stats: pd.DataFrame):
     )
     fig.update_layout(template="simple_white")
 
+    if format is not None:
+        img_bytes = fig.to_image(format=format, scale=scale, width=width, height=height)
+        fig = Image(img_bytes)
+    return fig
+
     return fig
